@@ -62,15 +62,3 @@ pub enum Extension {
     Python,
     NotExtensionSupported,
 }
-
-pub fn map_extension(ext: &str) -> Extension {
-    match ext {
-        "h" | "hh" | "hpp" | "hxx" | "h++" | "cc" | "cpp" | "cxx" | "c++" => Extension::Cpp,
-        "py" => Extension::Python,
-        _ => Extension::NotExtensionSupported,
-    }
-}
-
-pub fn is_extension_supported(ext: &str) -> bool {
-    map_extension(ext) != Extension::NotExtensionSupported
-}
