@@ -1,6 +1,6 @@
 /*
  *  Quick Test: CLI for stress testing in competitive programming
- *  Copyright (C) 2021 - Luis Miguel Báez
+ *  Copyright (C) 2021-present / Luis Miguel Báez
  *  License: MIT (See the LICENSE file in the repository root directory)
  */
 
@@ -9,4 +9,4 @@ pub mod cmd_cmp;
 pub mod cmd_example;
 pub mod cmd_run;
 pub mod cmd_setup;
-pub mod cmd_tle;
+pub mod cmd_stress;
