@@ -8,4 +8,4 @@ mod check_subcommand;
 mod cmp_subcommand;
 mod run_subcommand;
 mod setup_subcommand;
-mod tle_subcommand;
+mod stress_subcommand;
